"""Configuration file for ecs-task-ops."""
import json
import os

cfg = {}


def load_config():
    """Load configuration json file for this application."""
    global cfg, cfg_path
    for loc in (
        os.curdir,
        os.path.expanduser("~"),
        os.path.expanduser("~/.config/ecs-tasks-ops"),
        "/etc/ecs-tasks-ops",
        os.environ.get("ECS_TASKS_OPS_CONF"),
    ):
        try:
            if not loc:
                continue
            cfg_path = os.path.join(loc, "ecs-tasks-ops.json")
            with open(cfg_path) as source:
                print(f"Loading data from {cfg_path}")
                cfg = json.load(source)
        except IOError:
            pass



"""About widget."""
# -*- coding: utf-8 -*-
# Form implementation generated from reading ui file 'about.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.
from PyQt5 import QtCore
from PyQt5 import QtGui
from PyQt5 import QtWidgets


class UiAboutDialog(object):
    """Widget class for about dialog."""

    def setupUi(self, about_dialog):
        """Setup UI widgets."""
        about_dialog.setObjectName("about_dialog")
        about_dialog.resize(403, 246)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(about_dialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.vertical_layout = QtWidgets.QVBoxLayout()
        self.vertical_layout.setObjectName("vertical_layout")
        self.app_name = QtWidgets.QLabel(about_dialog)
        font = QtGui.QFont()
        font.setPointSize(26)
        self.app_name.setFont(font)
        self.app_name.setAlignment(QtCore.Qt.AlignCenter)
        self.app_name.setObjectName("app_name")
        self.vertical_layout.addWidget(self.app_name)
        self.author = QtWidgets.QLabel(about_dialog)
        self.author.setAlignment(QtCore.Qt.AlignCenter)
        self.author.setObjectName("author")
        self.vertical_layout.addWidget(self.author)
        self.help = QtWidgets.QLabel(about_dialog)
        self.help.setTextFormat(QtCore.Qt.MarkdownText)
        self.help.setAlignment(QtCore.Qt.AlignJustify | QtCore.Qt.AlignVCenter)
        self.help.setWordWrap(True)
        self.help.setObjectName("help")
        self.vertical_layout.addWidget(self.help)
        self.version = QtWidgets.QLabel(about_dialog)
        self.version.setAlignment(
            QtCore.Qt.AlignRight | QtCore.Qt.AlignTrailing | QtCore.Qt.AlignVCenter
        )
        self.version.setObjectName("version")
        self.vertical_layout.addWidget(self.version)
        self.button_box = QtWidgets.QDialogButtonBox(about_dialog)
        self.button_box.setOrientation(QtCore.Qt.Horizontal)
        self.button_box.setStandardButtons(
            QtWidgets.QDialogButtonBox.Cancel | QtWidgets.QDialogButtonBox.Ok
        )
        self.button_box.setObjectName("button_box")
        self.vertical_layout.addWidget(self.button_box)
        self.verticalLayout_2.addLayout(self.vertical_layout)

        self.retranslateUi(about_dialog)
        self.button_box.accepted.connect(about_dialog.accept)
        self.button_box.rejected.connect(about_dialog.reject)
        QtCore.QMetaObject.connectSlotsByName(about_dialog)

    def retranslateUi(self, about_dialog):
        """Translate widgets."""
        _translate = QtCore.QCoreApplication.translate
        about_dialog.setWindowTitle(_translate("about_dialog", "Dialog"))
        self.app_name.setText(_translate("about_dialog", "ECS Tasks Operations"))
        self.author.setText(
            _translate("about_dialog", "Pablo Palazon <ppalazon@antara.ws>")
        )
        self.help.setText(
            _translate(
                "about_dialog",
                '<html><head/><body><p>This application will let you access through SSH to your ECS resources such as containers instances and docker containers. It will also allow you to stop tasks and restart services. </p><p><span style=" font-weight:600;">This is not a replacement of ECS User interface</span></p></body></html>',
            )
        )
        self.version.setText(_translate("about_dialog", "Version: 0.1.0 "))



"""ECS pretty print for json objects."""
import datetime
import json
from json import JSONEncoder


# subclass JSONEncoder
class DateTimeEncoder(JSONEncoder):
    """DateTime Encoder for Json."""

    # Override the default method
    def default(self, obj):
        """Default method for encoder."""
        if isinstance(obj, (datetime.date, datetime.datetime)):
            return obj.isoformat()


def dumps(obj, indent=2):
    """Print the json object."""
    return json.dumps(obj, indent=indent, cls=DateTimeEncoder)



"""Clean and improve ecs data json."""
from itertools import chain

from ecs_tasks_ops import ecs_facade


def get_clusters():
    """Get a complete list of clusters."""
    return sorted(ecs_facade.get_cluster_list(), key=lambda x: x["clusterName"])


def get_services(cluster_name):
    """Get a complete list of services by cluster."""
    return sorted(
        ecs_facade.get_all_services(cluster_name), key=lambda x: x["serviceName"]
    )


def get_containers_instances(cluster_name):
    """Get a complete list of container instances by cluster."""
    return sorted(
        __improve_container_instance_info(cluster_name),
        key=lambda x: x["ec2InstanceId"],
    )


def get_tasks_cluster(cluster_name):
    """Get a complete list of task by cluster."""
    return sorted(__improve_cluster_tasks_info(cluster_name), key=lambda x: x["name"])


def get_tasks_service(cluster_name, service_name):
    """Get a complete list of services by clusters."""
    return sorted(
        __improve_service_tasks_info(cluster_name, service_name),
        key=lambda x: x["name"],
    )


def get_tasks_container_instance(cluster_name, containers_instance_arn):
    """Get a complete info for a container instance in a cluster."""
    return sorted(
        __improve_container_instance_tasks_info(cluster_name, containers_instance_arn),
        key=lambda x: x["name"],
    )


def get_containers_service(cluster_name, service_name):
    """Get a list of docker containers by a service and cluster."""
    return sorted(
        __improve_docker_container_info(cluster_name, service_name),
        key=lambda x: x["name"],
    )


def get_containers_tasks(cluster_name, task_arn):
    """Get a list of docker containers by task."""
    return sorted(
        __improve_docker_container_task_info(cluster_name, task_arn),
        key=lambda x: x["name"],
    )


def __improve_container_instance_info(cluster_name):
    """Extract more information about containers info for a specific cluster."""
    container_instances = ecs_facade.get_all_container_instances(cluster_name)
    for ci in container_instances:
        attrs = ci.get("attributes", [])
        attrs_vals = [a for a in attrs if "value" in a]
        ci["features"] = [a["name"] for a in attrs if "value" not in a]
        for attr in attrs_vals:
            ci[attr["name"]] = attr["value"]
        registered_resources = ci["registeredResources"]
        available_resources = ci["remainingResources"]
        ci["ami_id"] = __get_attr_value(attrs, "name", "ecs.ami-id", "value")
        ci["instance_type"] = __get_attr_value(
            attrs, "name", "ecs.instance-type", "value"
        )
        ci["availability_zone"] = __get_attr_value(
            attrs, "name", "ecs.availability-zone", "value"
        )
        ci["available_memory"] = __get_attr_value(
            available_resources, "name", "MEMORY", "integerValue"
        )
        ci["total_memory"] = __get_attr_value(
            registered_resources, "name", "MEMORY", "integerValue"
        )
        ci["available_cpu"] = __get_attr_value(
            available_resources, "name", "CPU", "integerValue"
        )
        ci["total_cpu"] = __get_attr_value(
            registered_resources, "name", "CPU", "integerValue"
        )
        ci["taken_ports"] = ", ".join(
            sorted(
                __get_attr_value(available_resources, "name", "PORTS", "stringSetValue")
            )
        )
        # ci["ami_id"] = next(obj for obj in attrs if obj["name"] == "ecs.ami-id")[
        #     "value"
        # ]
        # ci["instance_type"] = next(
        #     obj for obj in attrs if obj["name"] == "ecs.instance-type"
        # )["value"]
        # ci["availability_zone"] = next(
        #     obj for obj in attrs if obj["name"] == "ecs.availability-zone"
        # )["value"]
        # ci["available_memory"] = next(
        #     obj for obj in available_resources if obj["name"] == "MEMORY"
        # )["integerValue"]
        # ci["total_memory"] = next(
        #     obj for obj in registered_resources if obj["name"] == "MEMORY"
        # )["integerValue"]
        # ci["available_cpu"] = next(
        #     obj for obj in available_resources if obj["name"] == "CPU"
        # )["integerValue"]
        # ci["total_cpu"] = next(
        #     obj for obj in registered_resources if obj["name"] == "CPU"
        # )["integerValue"]
        # ci["taken_ports"] = ", ".join(
        #     sorted(
        #         next(obj for obj in available_resources if obj["name"] == "PORTS")[
        #             "stringSetValue"
        #         ]
        #     )
        # )
    return container_instances


def __get_attr_value(attr_list, filter_name, filter_value, attr_name):
    """Get value for this attribute."""
    o = next(obj for obj in attr_list if obj[filter_name] == filter_value)
    if o:
        return o[attr_name]
    return None


def __improve_tasks_info(cluster_name, tasks):
    """Get more information for a list of tasks."""
    containers_instances = get_containers_instances(cluster_name)
    for task in tasks:
        for inst in containers_instances:
            if inst["containerInstanceArn"] == task["containerInstanceArn"]:
                task["ec2InstanceId"] = inst["ec2InstanceId"]
        task["networks"] = [
            __extract_network_from_docker_container(c) for c in task["containers"]
        ]
        # task['name'] = task['taskDefinitionArn'].split("/")[1] + " - " + task['taskArn'].split("/")[1]
        task["name"] = task["taskDefinitionArn"].split("/")[1]
    return tasks


def __improve_one_tasks_info(cluster_name, task_arn):
    """Get more information from a cluster and task id."""
    tasks = ecs_facade.get_describe_tasks(cluster_name, [task_arn])
    return __improve_tasks_info(cluster_name, tasks)


def __improve_service_tasks_info(cluster_name, service_name):
    """Get more information for a list of task of a service."""
    tasks = ecs_facade.get_all_tasks_services(cluster_name, service_name)
    return __improve_tasks_info(cluster_name, tasks)


def __improve_container_instance_tasks_info(cluster_name, container_instance):
    """Get more information for a list of task of a container instance."""
    tasks = ecs_facade.get_all_tasks_container(cluster_name, container_instance)
    return __improve_tasks_info(cluster_name, tasks)


def __improve_cluster_tasks_info(cluster_name):
    """Get more infomation for a list of tasks of a cluster."""
    tasks = ecs_facade.get_all_tasks_cluster(cluster_name)
    return __improve_tasks_info(cluster_name, tasks)


def __extract_docker_containers(task):
    """Extract docker container information for a task."""
    containers = task.get("containers", [])
    for container in containers:
        container["ec2InstanceId"] = task.get("ec2InstanceId", "")
        container["networks"] = __extract_network_from_docker_container(container)
    return containers


def __extract_network_from_docker_container(docker_container):
    """Extract network information for a docker container."""
    network_bindings = docker_container.get("networkBindings")
    bindings = []
    if network_bindings:
        bindings = [
            network["bindIP"]
            + " ("
            + str(network["hostPort"])
            + "[host] -> "
            + str(network["containerPort"])
            + "[network])"
            for network in network_bindings
        ]
    if bindings is []:
        bindings = "no network binding"
    else:
        bindings = ", ".join(bindings)
    return docker_container["name"] + " -> " + bindings


def __improve_docker_container_info(cluster_name, service_name):
    """Get a list of docker container for a list of task of a service."""
    tasks = __improve_service_tasks_info(cluster_name, service_name)
    containers = list(
        chain.from_iterable([__extract_docker_containers(task) for task in tasks])
    )
    return containers


def __improve_docker_container_task_info(cluster_name, task_arn):
    """Get a list of docker container for a list of task of a task."""
    tasks = __improve_one_tasks_info(cluster_name, task_arn)
    containers = list(
        chain.from_iterable([__extract_docker_containers(task) for task in tasks])
    )
    return containers



"""ECS Facade for ecs-tasks-ops."""
from itertools import chain

import boto3

# ecs_client = boto3.client("ecs")


def ecs_client():
    """Get ecs client."""
    return boto3.client("ecs")


def get_ecs_list(operation_name, response_attribute, **operation_params):
    """Get a complete list of elements by operation_name."""
    paginator = ecs_client().get_paginator(operation_name)
    operation_params["PaginationConfig"] = {"MaxItems": 100}
    paginator_ite = paginator.paginate(**operation_params)
    return list(
        chain.from_iterable(
            [resp.get(response_attribute, []) for resp in paginator_ite]
        )
    )


def get_cluster_list():
    """Get a complete list with cluster information."""
    list_clusters = get_ecs_list("list_clusters", "clusterArns")
    return ecs_client().describe_clusters(clusters=list_clusters).get("clusters", [])


def get_describe_services(cluster_name, services_arns):
    """Get information about a list of services arns."""
    return (
        ecs_client()
        .describe_services(cluster=cluster_name, services=services_arns)
        .get("services", [])
    )


def get_describe_tasks(cluster_name, tasks_arns):
    """Get information about a list of tasks."""
    return (
        ecs_client()
        .describe_tasks(cluster=cluster_name, tasks=tasks_arns)
        .get("tasks", [])
    )


def get_describe_container_instances(cluster_name, container_instances_arns):
    """Get information about a list of container instances."""
    return (
        ecs_client()
        .describe_container_instances(
            cluster=cluster_name, containerInstances=container_instances_arns
        )
        .get("containerInstances", [])
    )


def get_all_services(cluster_name):
    """Get information about all services defined in a cluster."""
    list_services_arns = get_ecs_list(
        "list_services", "serviceArns", cluster=cluster_name
    )
    # Max request per describe_services are 10 services arns, so we slice them 10 by 10, and request each 10
    slices = [slice(i, i + 10, 1) for i in range(0, len(list_services_arns), 10)]
    services = list(
        chain.from_iterable(
            [
                get_describe_services(cluster_name, list_services_arns[slc])
                for slc in slices
            ]
        )
    )
    return services


def get_all_container_instances(cluster_name):
    """Get information about all container instances defined in a cluster."""
    list_container_instances_arns = get_ecs_list(
        "list_container_instances", "containerInstanceArns", cluster=cluster_name
    )
    # Max request per describe_services are 10 services arns, so we slice them 100 by 100, and request each 100
    slices = [
        slice(i, i + 100, 1) for i in range(0, len(list_container_instances_arns), 100)
    ]
    containers_instances = list(
        chain.from_iterable(
            [
                get_describe_container_instances(
                    cluster_name, list_container_instances_arns[slc]
                )
                for slc in slices
            ]
        )
    )
    return containers_instances


def get_all_tasks_cluster(cluster_name):
    """Get information about all tasks defined in a cluster for a service."""
    list_tasks_arns = get_ecs_list("list_tasks", "taskArns", cluster=cluster_name)
    # Max request per describe_services are 100 services arns, so we slice them 100 by 100, and request each 100
    slices = [slice(i, i + 100, 1) for i in range(0, len(list_tasks_arns), 100)]
    tasks = list(
        chain.from_iterable(
            [get_describe_tasks(cluster_name, list_tasks_arns[slc]) for slc in slices]
        )
    )
    return tasks


def get_all_tasks_services(cluster_name, service_name):
    """Get information about all tasks defined in a cluster for a service."""
    list_tasks_arns = get_ecs_list(
        "list_tasks", "taskArns", cluster=cluster_name, serviceName=service_name
    )
    # Max request per describe_services are 100 services arns, so we slice them 100 by 100, and request each 100
    slices = [slice(i, i + 100, 1) for i in range(0, len(list_tasks_arns), 100)]
    tasks = list(
        chain.from_iterable(
            [get_describe_tasks(cluster_name, list_tasks_arns[slc]) for slc in slices]
        )
    )
    return tasks


def get_all_tasks_container(cluster_name, container_arn):
    """Get information about all tasks defined in a cluster for a service."""
    list_tasks_arns = get_ecs_list(
        "list_tasks", "taskArns", cluster=cluster_name, containerInstance=container_arn
    )
    # Max request per describe_services are 100 services arns, so we slice them 100 by 100, and request each 100
    slices = [slice(i, i + 100, 1) for i in range(0, len(list_tasks_arns), 100)]
    tasks = list(
        chain.from_iterable(
            [get_describe_tasks(cluster_name, list_tasks_arns[slc]) for slc in slices]
        )
    )
    return tasks


def stop_task(cluster_name, task_arn, reason=""):
    """Stop a specific task."""
    return (
        ecs_client()
        .stop_task(cluster=cluster_name, task=task_arn, reason=reason)
        .get("task", {})
    )


def restart_service(cluster_name, service_arn, force_new_deployment=False):
    """Stop a specific task."""
    return (
        ecs_client()
        .update_service(
            cluster=cluster_name,
            service=service_arn,
            forceNewDeployment=force_new_deployment,
        )
        .get("service", {})
    )



"""Main Widget widget."""
# -*- coding: utf-8 -*-
# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.
from PyQt5 import QtCore
from PyQt5 import QtWidgets

from ecs_tasks_ops_qt5.qt5_ecs import ECSAttributesTreeWidget
from ecs_tasks_ops_qt5.qt5_ecs import ECSElementsTreeWidget
from ecs_tasks_ops_qt5.qt5_ecs import ECSTabView


class UiMainWindow(object):
    """Widget composition for application."""

    def setupUi(self, main_window):
        """Inialization."""
        main_window.setObjectName("main_window")
        main_window.resize(800, 600)
        self.centralwidget = QtWidgets.QWidget(main_window)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.splitter_horizontal = QtWidgets.QSplitter(self.centralwidget)
        self.splitter_horizontal.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_horizontal.setObjectName("splitter_horizontal")
        self.splitter_vertical = QtWidgets.QSplitter(self.splitter_horizontal)
        self.splitter_vertical.setOrientation(QtCore.Qt.Vertical)
        self.splitter_vertical.setObjectName("splitter_vertical")
        self.ecs_elements = ECSElementsTreeWidget(self.splitter_vertical)
        self.ecs_elements.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.ecs_elements.setIndentation(12)
        self.ecs_elements.setObjectName("ecs_elements")
        self.attributes = ECSAttributesTreeWidget(self.splitter_vertical)
        self.attributes.setObjectName("attributes")
        self.tabWidget = ECSTabView(self.splitter_horizontal)
        self.tabWidget.setTabsClosable(True)
        self.tabWidget.setMovable(True)
        self.tabWidget.setObjectName("tabWidget")
        self.verticalLayout.addWidget(self.splitter_horizontal)
        main_window.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(main_window)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 20))
        self.menubar.setObjectName("menubar")
        self.menu_ecs_taks_ops = QtWidgets.QMenu(self.menubar)
        self.menu_ecs_taks_ops.setObjectName("menu_ecs_taks_ops")
        self.menu_file = QtWidgets.QMenu(self.menubar)
        self.menu_file.setObjectName("menu_file")
        main_window.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(main_window)
        self.statusbar.setObjectName("statusbar")
        main_window.setStatusBar(self.statusbar)
        self.action_about = QtWidgets.QAction(main_window)
        self.action_about.setObjectName("action_about")
        self.action_quit = QtWidgets.QAction(main_window)
        self.action_quit.setObjectName("action_quit")
        self.action_reload_clusters = QtWidgets.QAction(main_window)
        self.action_reload_clusters.setObjectName("action_reload_clusters")
        self.action_reload_config = QtWidgets.QAction(main_window)
        self.action_reload_config.setObjectName("action_reload_config")
        self.menu_ecs_taks_ops.addAction(self.action_about)
        self.menu_file.addAction(self.action_reload_config)
        self.menu_file.addAction(self.action_reload_clusters)
        self.menu_file.addSeparator()
        self.menu_file.addAction(self.action_quit)
        self.menubar.addAction(self.menu_file.menuAction())
        self.menubar.addAction(self.menu_ecs_taks_ops.menuAction())

        self.retranslateUi(main_window)
        self.tabWidget.setCurrentIndex(-1)
        QtCore.QMetaObject.connectSlotsByName(main_window)

    def retranslateUi(self, main_window):
        """Translate widget."""
        _translate = QtCore.QCoreApplication.translate
        main_window.setWindowTitle(_translate("main_window", "MainWindow"))
        self.ecs_elements.headerItem().setText(
            0, _translate("main_window", "ECS Elements")
        )
        self.attributes.headerItem().setText(0, _translate("main_window", "Name"))
        self.attributes.headerItem().setText(1, _translate("main_window", "Value"))
        self.menu_ecs_taks_ops.setTitle(_translate("main_window", "Help"))
        self.menu_file.setTitle(_translate("main_window", "File"))
        self.action_about.setText(_translate("main_window", "About"))
        self.action_about.setShortcut(_translate("main_window", "Ctrl+A"))
        self.action_quit.setText(_translate("main_window", "Quit"))
        self.action_quit.setShortcut(_translate("main_window", "Ctrl+Q"))
        self.action_reload_clusters.setText(
            _translate("main_window", "Reload Clusters")
        )
        self.action_reload_clusters.setShortcut(_translate("main_window", "Ctrl+R"))
        self.action_reload_config.setText(_translate("main_window", "Reload Config"))



"""Qt5 User Interface for ECS Tasks Ops."""
import sys

import pkg_resources
from PyQt5 import QtWidgets

from ecs_tasks_ops import ecs_conf
from ecs_tasks_ops_qt5.about import UiAboutDialog
from ecs_tasks_ops_qt5.main_window import UiMainWindow


class AboutDialog(QtWidgets.QDialog, UiAboutDialog):
    """About Dialog widget."""

    def __init__(self, *args, **kwargs):
        """Initialize about dialog."""
        super(AboutDialog, self).__init__(*args, **kwargs)
        self.setupUi(self)

        version = pkg_resources.get_distribution("ecs_tasks_ops").version
        self.version.setText(f"Version: {version}")


class MainWindow(QtWidgets.QMainWindow, UiMainWindow):
    """Main Window for this application."""

    def __init__(self, *args, obj=None, **kwargs):
        """Initialize application and connections between widgets."""
        super(MainWindow, self).__init__(*args, **kwargs)
        self.setupUi(self)

        self.setWindowTitle("ECS Tasks Operations")

        self.splitter_horizontal.setSizes([100, 400])
        self.splitter_vertical.setSizes([200, 100])
        self.ecs_elements.sig_status_changed.connect(self.statusbar.showMessage)
        self.attributes.sig_status_changed.connect(self.statusbar.showMessage)

        self.action_quit.triggered.connect(self.close)
        self.action_about.triggered.connect(self.open_about)
        self.ecs_elements.currentItemChanged[
            "QTreeWidgetItem*", "QTreeWidgetItem*"
        ].connect(self.attributes.update_attributes)
        self.action_reload_clusters.triggered.connect(
            self.ecs_elements.reload_cluster_info
        )
        self.action_reload_config.triggered.connect(self.reload_conf)
        self.ecs_elements.sig_command_show_detail["QTreeWidgetItem*"].connect(
            self.tabWidget.show_detail
        )
        self.ecs_elements.sig_command_container_ssh["QTreeWidgetItem*"].connect(
            self.tabWidget.container_ssh
        )
        self.ecs_elements.sig_command_task_log["QTreeWidgetItem*"].connect(
            self.tabWidget.task_log
        )
        self.ecs_elements.sig_command_task_stop["QTreeWidgetItem*"].connect(
            self.tabWidget.task_stop
        )
        self.ecs_elements.sig_command_docker_log["QTreeWidgetItem*"].connect(
            self.tabWidget.docker_container_log
        )
        self.ecs_elements.sig_command_docker_exec["QTreeWidgetItem*"].connect(
            self.tabWidget.docker_container_exec
        )
        self.ecs_elements.sig_command_service_show_events["QTreeWidgetItem*"].connect(
            self.tabWidget.service_events
        )
        self.ecs_elements.sig_command_service_restart["QTreeWidgetItem*"].connect(
            self.tabWidget.service_restart
        )

    def open_about(self):
        """Open About Dialog widget."""
        about_dialog = AboutDialog(self)
        about_dialog.exec_()

    def reload_conf(self):
        """Reload configuration file."""
        ecs_conf.load_config()
        self.statusbar.showMessage("Reloading configuration")


def main_gui():
    """Main method to start QT5 application from cli."""
    app = QtWidgets.QApplication(sys.argv)

    window = MainWindow()
    window.show()
    app.exec()


if __name__ == "__main__":
    main_gui()
